==> hboard-1.0-rc1.tar.gz: hboard/admin.php <==
<?php

/* EtchiBoard Version 1.0
     admin.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>EtchiBoard Admin Log-in</title>
</head>

<body onload="document.loginform.password.focus();">
<table align="center" border="1" cellspacing="0" width="319" bordercolordark="white" bordercolorlight="black">
    <tr>
        <td width="309" bgcolor="#EAEAEA">
            <p><span style="font-size:9pt;"><b><font color="#676767">&nbsp;EtchiBoard  α</font></b></span></p>
        </td>
    </tr>
    <tr>
        <td width="309" height="74">
            <form name="loginform" target="_self" method="post" action="admin_login.php">
			 <input type="hidden" name="from" value="<?=$from?>">

                <p align="center"><span style="font-size:9pt;"><br><font color="blue"> йȣ</font> 
                Է ּ.<br><br><input type="password" name="password" size="14"> 
                <input type="submit" name="formSend" value="Ȯ"> 
                <input type="button" name="cancel" value="" onClick="window.close()"></span></p>

			</form>
        </td>
    </tr>
</table>
<p><span style="font-size:9pt;">&nbsp;</span></p>

</body>
</html>

==> hboard-1.0.4.tar.gz: hboard/admin.php <==
<?php



/* EtchiBoard Version 1.0

     admin.php

     http://etchibbs.kldp.net */



/***************************************************************************

 *

 *   This program is free software; you can redistribute it and/or modify

 *   it under the terms of the GNU General Public License as published by

 *   the Free Software Foundation; either version 2 of the License, or

 *   (at your option) any later version.

 *

 ***************************************************************************/



?>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">

<html>

<head>

<title>EtchiBoard Admin Log-in</title>

</head>



<body onload="document.loginform.password.focus();">

<table align="center" border="1" cellspacing="0" width="319" bordercolordark="white" bordercolorlight="black">

    <tr>

        <td width="309" bgcolor="#EAEAEA">

            <p><span style="font-size:9pt;"><b><font color="#676767">&nbsp;EtchiBoard  α</font></b></span></p>

        </td>

    </tr>

    <tr>

        <td width="309" height="74">

            <form name="loginform" target="_self" method="post" action="admin_login.php">

			 <input type="hidden" name="from" value="<?php echo $from?>">



                <p align="center"><span style="font-size:9pt;"><br><font color="blue"> йȣ</font> 

                Է ּ.<br><br><input type="password" name="password" size="14"> 

                <input type="submit" name="formSend" value="Ȯ"> 

                <input type="button" name="cancel" value="" onClick="window.close()"></span></p>



			</form>

        </td>

    </tr>

</table>

<p><span style="font-size:9pt;">&nbsp;</span></p>



</body>

</html>
